@@ -12,10 +12,10 @@ from those classes, as well as any overridden or additional methods or
 attributes defined in this subclass.
 """
 
-# Copyright (c) 2001 - 2015 The SCons Foundation
+# Copyright (c) 2001 - 2016 The SCons Foundation
 from __future__ import division
 
-__revision__ = "QMTest/TestSCons.py rel_2.4.1:3453:73fefd3ea0b0 2015/11/09 03:25:05 bdbaddog"
+__revision__ = "QMTest/TestSCons.py rel_2.5.0:3543:937e55cd78f7 2016/04/09 11:29:54 bdbaddog"
 
 import os
 import re
@@ -34,16 +34,16 @@ from TestCmd import PIPE
 # here provides some independent verification that what we packaged
 # conforms to what we expect.
 
-default_version = '2.4.1'
+default_version = '2.5.0'
 
-python_version_unsupported = (2, 3, 0)
+python_version_unsupported = (2, 6, 0)
 python_version_deprecated = (2, 7, 0)
 
 # In the checked-in source, the value of SConsVersion in the following
 # line must remain "__ VERSION __" (without the spaces) so the built
 # version in build/QMTest/TestSCons.py contains the actual version
 # string of the packages that have been built.
-SConsVersion = '2.4.1'
+SConsVersion = '2.5.0'
 if SConsVersion == '__' + 'VERSION' + '__':
     SConsVersion = default_version
 
@@ -201,6 +201,7 @@ class TestSCons(TestCommon):
     """
 
     scons_version = SConsVersion
+    javac_is_gcj = False
 
     def __init__(self, **kw):
         """Initialize an SCons testing object.
@@ -768,8 +769,13 @@ class TestSCons(TestCommon):
             m = re.search(r'javac (\d\.\d)', self.stderr())
             if m:
                 version = m.group(1)
+                self.javac_is_gcj = False
+            elif self.stderr().find('gcj'):
+                version='1.2'
+                self.javac_is_gcj = True
             else:
                 version = None
+                self.javac_is_gcj = False
         return where_javac, version
 
     def java_where_javah(self, version=None):
@@ -792,6 +798,7 @@ class TestSCons(TestCommon):
             self.skip_test("Could not find Java rmic, skipping non-simulated test(s).\n")
         return where_rmic
 
+    
     def java_get_class_files(self, dir):
         result = []
         for dirpath, dirnames, filenames in os.walk(dir):
