@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2001 - 2015 The SCons Foundation
+# Copyright (c) 2001 - 2016 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -21,7 +21,7 @@
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/Variables/VariablesTests.py rel_2.4.1:3453:73fefd3ea0b0 2015/11/09 03:25:05 bdbaddog"
+__revision__ = "src/engine/SCons/Variables/VariablesTests.py rel_2.5.0:3543:937e55cd78f7 2016/04/09 11:29:54 bdbaddog"
 
 import sys
 import unittest
@@ -273,6 +273,22 @@ class VariablesTestCase(unittest.TestCase):
         opts.Update(env, {})
         assert 'ANSWER' not in env
 
+    def test_noaggregation(self):
+        """Test that the 'files' and 'args' attributes of the Variables class
+           don't aggregate entries from one instance to another.
+           This used to be a bug in SCons version 2.4.1 and earlier.
+        """
+
+        opts = SCons.Variables.Variables()
+        opts.files.append('custom.py')
+        opts.args['ANSWER'] = 54
+        nopts = SCons.Variables.Variables()
+
+        # Ensure that both attributes are initialized to
+        # an empty list and dict, respectively. 
+        assert len(nopts.files) == 0
+        assert len(nopts.args) == 0        
+
     def test_args(self):
         """Test updating an Environment with arguments overridden"""
 
